/*
 * Copyright (c) 2017, 2018, Oracle and/or its affiliates. All rights reserved.
 * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 */
/*
 @ApiInfo(
 group="GraalVM SDK"
 )
 */
/**
 * The GraalVM SDK collections package contains memory efficient data structures.
 *
 * @see jdk.internal.vm.compiler.collections.EconomicMap
 * @see jdk.internal.vm.compiler.collections.EconomicSet
 *
 * @since 1.0
 */


















package jdk.internal.vm.compiler.collections;
